@@ -1,4 +1,3 @@
 from .data import COINNDataLoader, COINNDataset
 from .nodes import COINNLocal, COINNRemote
-from .trainer import COINNTrainer
-from .pool import PooledTrainer
+from .trainer import COINNTrainer, PooledTrainer
